# -*- coding: utf-8 -*-
info = {
    "name": "is",
    "date_order": "DMY",
    "january": [
        "janúar",
        "jan"
    ],
    "february": [
        "febrúar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "apríl",
        "apr"
    ],
    "may": [
        "maí"
    ],
    "june": [
        "júní",
        "jún"
    ],
    "july": [
        "júlí",
        "júl"
    ],
    "august": [
        "ágúst",
        "ágú"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "október",
        "okt"
    ],
    "november": [
        "nóvember",
        "nóv"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mánudagur",
        "mán"
    ],
    "tuesday": [
        "þriðjudagur",
        "þri"
    ],
    "wednesday": [
        "miðvikudagur",
        "mið"
    ],
    "thursday": [
        "fimmtudagur",
        "fim"
    ],
    "friday": [
        "föstudagur",
        "fös"
    ],
    "saturday": [
        "laugardagur",
        "lau"
    ],
    "sunday": [
        "sunnudagur",
        "sun"
    ],
    "am": [
        "fh"
    ],
    "pm": [
        "eh"
    ],
    "year": [
        "ár"
    ],
    "month": [
        "mánuður",
        "mán"
    ],
    "week": [
        "vika",
        "v"
    ],
    "day": [
        "dagur",
        "d"
    ],
    "hour": [
        "klukkustund",
        "klst"
    ],
    "minute": [
        "mínúta",
        "mín"
    ],
    "second": [
        "sekúnda",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "á síðasta ári"
        ],
        "0 year ago": [
            "á þessu ári"
        ],
        "in 1 year": [
            "á næsta ári"
        ],
        "1 month ago": [
            "í síðasta mánuði",
            "í síðasta mán"
        ],
        "0 month ago": [
            "í þessum mánuði",
            "í þessum mán"
        ],
        "in 1 month": [
            "í næsta mánuði",
            "í næsta mán"
        ],
        "1 week ago": [
            "í síðustu viku"
        ],
        "0 week ago": [
            "í þessari viku"
        ],
        "in 1 week": [
            "í næstu viku"
        ],
        "1 day ago": [
            "í gær"
        ],
        "0 day ago": [
            "í dag"
        ],
        "in 1 day": [
            "á morgun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "núna"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "eftir (\\d+) ár"
        ],
        "\\1 year ago": [
            "fyrir (\\d+) ári",
            "fyrir (\\d+) árum"
        ],
        "in \\1 month": [
            "eftir (\\d+) mánuð",
            "eftir (\\d+) mánuði",
            "eftir (\\d+) mán"
        ],
        "\\1 month ago": [
            "fyrir (\\d+) mánuði",
            "fyrir (\\d+) mánuðum",
            "fyrir (\\d+) mán"
        ],
        "in \\1 week": [
            "eftir (\\d+) viku",
            "eftir (\\d+) vikur"
        ],
        "\\1 week ago": [
            "fyrir (\\d+) viku",
            "fyrir (\\d+) vikum"
        ],
        "in \\1 day": [
            "eftir (\\d+) dag",
            "eftir (\\d+) daga"
        ],
        "\\1 day ago": [
            "fyrir (\\d+) degi",
            "fyrir (\\d+) dögum"
        ],
        "in \\1 hour": [
            "eftir (\\d+) klukkustund",
            "eftir (\\d+) klukkustundir",
            "eftir (\\d+) klst"
        ],
        "\\1 hour ago": [
            "fyrir (\\d+) klukkustund",
            "fyrir (\\d+) klukkustundum",
            "fyrir (\\d+) klst"
        ],
        "in \\1 minute": [
            "eftir (\\d+) mínútu",
            "eftir (\\d+) mínútur",
            "eftir (\\d+) mín"
        ],
        "\\1 minute ago": [
            "fyrir (\\d+) mínútu",
            "fyrir (\\d+) mínútum",
            "fyrir (\\d+) mín"
        ],
        "in \\1 second": [
            "eftir (\\d+) sekúndu",
            "eftir (\\d+) sekúndur",
            "eftir (\\d+) sek"
        ],
        "\\1 second ago": [
            "fyrir (\\d+) sekúndu",
            "fyrir (\\d+) sekúndum",
            "fyrir (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "xog",
    "date_order": "DMY",
    "january": [
        "janwaliyo",
        "jan"
    ],
    "february": [
        "febwaliyo",
        "feb"
    ],
    "march": [
        "marisi",
        "mar"
    ],
    "april": [
        "apuli",
        "apu"
    ],
    "may": [
        "maayi",
        "maa"
    ],
    "june": [
        "juuni",
        "juu"
    ],
    "july": [
        "julaayi",
        "jul"
    ],
    "august": [
        "agusito",
        "agu"
    ],
    "september": [
        "sebuttemba",
        "seb"
    ],
    "october": [
        "okitobba",
        "oki"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "desemba",
        "des"
    ],
    "monday": [
        "balaza",
        "bala"
    ],
    "tuesday": [
        "owokubili",
        "kubi"
    ],
    "wednesday": [
        "owokusatu",
        "kusa"
    ],
    "thursday": [
        "olokuna",
        "kuna"
    ],
    "friday": [
        "olokutaanu",
        "kuta"
    ],
    "saturday": [
        "olomukaaga",
        "muka"
    ],
    "sunday": [
        "sabiiti",
        "sabi"
    ],
    "am": [
        "munkyo"
    ],
    "pm": [
        "eigulo"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esabiiti"
    ],
    "day": [
        "olunaku"
    ],
    "hour": [
        "essawa"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obutikitiki"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "edho"
        ],
        "0 day ago": [
            "olwaleelo (leelo)"
        ],
        "in 1 day": [
            "enkyo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "lb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mäerz",
        "mäe"
    ],
    "april": [
        "abrëll",
        "abr"
    ],
    "may": [
        "mee"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "dezember",
        "dez"
    ],
    "monday": [
        "méindeg",
        "méi"
    ],
    "tuesday": [
        "dënschdeg",
        "dën"
    ],
    "wednesday": [
        "mëttwoch",
        "mët"
    ],
    "thursday": [
        "donneschdeg",
        "don"
    ],
    "friday": [
        "freideg",
        "fre"
    ],
    "saturday": [
        "samschdeg",
        "sam"
    ],
    "sunday": [
        "sonndeg",
        "son"
    ],
    "am": [
        "moies"
    ],
    "pm": [
        "nomëttes"
    ],
    "year": [
        "joer",
        "j"
    ],
    "month": [
        "mount",
        "m"
    ],
    "week": [
        "woch",
        "w"
    ],
    "day": [
        "dag",
        "d"
    ],
    "hour": [
        "stonn",
        "st"
    ],
    "minute": [
        "minutt",
        "min"
    ],
    "second": [
        "sekonn",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "lescht joer"
        ],
        "0 year ago": [
            "dëst joer"
        ],
        "in 1 year": [
            "nächst joer"
        ],
        "1 month ago": [
            "leschte mount"
        ],
        "0 month ago": [
            "dëse mount"
        ],
        "in 1 month": [
            "nächste mount"
        ],
        "1 week ago": [
            "lescht woch"
        ],
        "0 week ago": [
            "dës woch"
        ],
        "in 1 week": [
            "nächst woch"
        ],
        "1 day ago": [
            "gëschter"
        ],
        "0 day ago": [
            "haut"
        ],
        "in 1 day": [
            "muer"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "an (\\d+) joer",
            "an (\\d+) j"
        ],
        "\\1 year ago": [
            "virun (\\d+) joer",
            "virun (\\d+) j"
        ],
        "in \\1 month": [
            "an (\\d+) mount",
            "an (\\d+) m"
        ],
        "\\1 month ago": [
            "virun (\\d+) mount",
            "virun (\\d+) m"
        ],
        "in \\1 week": [
            "an (\\d+) woch",
            "an (\\d+) w"
        ],
        "\\1 week ago": [
            "virun (\\d+) woch",
            "virun (\\d+) w"
        ],
        "in \\1 day": [
            "an (\\d+) dag",
            "an (\\d+) d"
        ],
        "\\1 day ago": [
            "virun (\\d+) dag",
            "virun (\\d+) d"
        ],
        "in \\1 hour": [
            "an (\\d+) stonn",
            "an (\\d+) st"
        ],
        "\\1 hour ago": [
            "virun (\\d+) stonn",
            "virun (\\d+) st"
        ],
        "in \\1 minute": [
            "an (\\d+) minutt",
            "an (\\d+) min"
        ],
        "\\1 minute ago": [
            "virun (\\d+) minutt",
            "virun (\\d+) min"
        ],
        "in \\1 second": [
            "an (\\d+) sekonn",
            "an (\\d+) sek"
        ],
        "\\1 second ago": [
            "virun (\\d+) sekonn",
            "virun (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "uz-Latn",
    "date_order": "DMY",
    "january": [
        "yanvar",
        "yan"
    ],
    "february": [
        "fevral",
        "fev"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "aprel",
        "apr"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyun",
        "iyn"
    ],
    "july": [
        "iyul",
        "iyl"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "sentabr",
        "sen"
    ],
    "october": [
        "oktabr",
        "okt"
    ],
    "november": [
        "noyabr",
        "noy"
    ],
    "december": [
        "dekabr",
        "dek"
    ],
    "monday": [
        "dushanba",
        "dush"
    ],
    "tuesday": [
        "seshanba",
        "sesh"
    ],
    "wednesday": [
        "chorshanba",
        "chor"
    ],
    "thursday": [
        "payshanba",
        "pay"
    ],
    "friday": [
        "juma",
        "jum"
    ],
    "saturday": [
        "shanba",
        "shan"
    ],
    "sunday": [
        "yakshanba",
        "yak"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daqiqa",
        "daq"
    ],
    "second": [
        "soniya",
        "son"
    ],
    "relative-type": {
        "1 year ago": [
            "o‘tgan yil",
            "o'tgan yil"
        ],
        "0 year ago": [
            "shu yil",
            "bu yil"
        ],
        "in 1 year": [
            "keyingi yil"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "1 day ago": [
            "kecha"
        ],
        "0 day ago": [
            "bugun"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 second ago": [
            "hozir"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) yildan keyin"
        ],
        "\\1 year ago": [
            "(\\d+) yil oldin"
        ],
        "in \\1 month": [
            "(\\d+) oydan keyin"
        ],
        "\\1 month ago": [
            "(\\d+) oy oldin"
        ],
        "in \\1 week": [
            "(\\d+) haftadan keyin"
        ],
        "\\1 week ago": [
            "(\\d+) hafta oldin"
        ],
        "in \\1 day": [
            "(\\d+) kundan keyin"
        ],
        "\\1 day ago": [
            "(\\d+) kun oldin"
        ],
        "in \\1 hour": [
            "(\\d+) soatdan keyin"
        ],
        "\\1 hour ago": [
            "(\\d+) soat oldin"
        ],
        "in \\1 minute": [
            "(\\d+) daqiqadan keyin"
        ],
        "\\1 minute ago": [
            "(\\d+) daqiqa oldin"
        ],
        "in \\1 second": [
            "(\\d+) soniyadan keyin"
        ],
        "\\1 second ago": [
            "(\\d+) soniya oldin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "tzm",
    "date_order": "DMY",
    "january": [
        "yennayer",
        "yen"
    ],
    "february": [
        "yebrayer",
        "yeb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "ibrir",
        "ibr"
    ],
    "may": [
        "mayyu",
        "may"
    ],
    "june": [
        "yunyu",
        "yun"
    ],
    "july": [
        "yulyuz",
        "yul"
    ],
    "august": [
        "ɣuct",
        "ɣuc"
    ],
    "september": [
        "cutanbir",
        "cut"
    ],
    "october": [
        "kṭuber",
        "kṭu"
    ],
    "november": [
        "nwanbir",
        "nwa"
    ],
    "december": [
        "dujanbir",
        "duj"
    ],
    "monday": [
        "aynas",
        "ayn"
    ],
    "tuesday": [
        "asinas",
        "asn"
    ],
    "wednesday": [
        "akras",
        "akr"
    ],
    "thursday": [
        "akwas",
        "akw"
    ],
    "friday": [
        "asimwas",
        "asm"
    ],
    "saturday": [
        "asiḍyas",
        "asḍ"
    ],
    "sunday": [
        "asamas",
        "asa"
    ],
    "am": [
        "zdat azal"
    ],
    "pm": [
        "ḍeffir aza"
    ],
    "year": [
        "asseggas"
    ],
    "month": [
        "ayur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdat"
    ],
    "second": [
        "tusnat"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "assenaṭ"
        ],
        "0 day ago": [
            "assa"
        ],
        "in 1 day": [
            "asekka"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "naq",
    "date_order": "DMY",
    "january": [
        "ǃkhanni",
        "jan"
    ],
    "february": [
        "ǃkhanǀgôab",
        "feb"
    ],
    "march": [
        "ǀkhuuǁkhâb",
        "mar"
    ],
    "april": [
        "ǃhôaǂkhaib",
        "apr"
    ],
    "may": [
        "ǃkhaitsâb",
        "may"
    ],
    "june": [
        "gamaǀaeb",
        "jun"
    ],
    "july": [
        "ǂkhoesaob",
        "jul"
    ],
    "august": [
        "aoǁkhuumûǁkhâb",
        "aug"
    ],
    "september": [
        "taraǀkhuumûǁkhâb",
        "sep"
    ],
    "october": [
        "ǂnûǁnâiseb",
        "oct"
    ],
    "november": [
        "ǀhooǂgaeb",
        "nov"
    ],
    "december": [
        "hôasoreǁkhâb",
        "dec"
    ],
    "monday": [
        "mantaxtsees",
        "ma"
    ],
    "tuesday": [
        "denstaxtsees",
        "de"
    ],
    "wednesday": [
        "wunstaxtsees",
        "wu"
    ],
    "thursday": [
        "dondertaxtsees",
        "do"
    ],
    "friday": [
        "fraitaxtsees",
        "fr"
    ],
    "saturday": [
        "satertaxtsees",
        "sat"
    ],
    "sunday": [
        "sontaxtsees",
        "son"
    ],
    "am": [
        "ǁgoagas"
    ],
    "pm": [
        "ǃuias"
    ],
    "year": [
        "kurib"
    ],
    "month": [
        "ǁkhâb"
    ],
    "week": [
        "wekheb"
    ],
    "day": [
        "tsees"
    ],
    "hour": [
        "iiri"
    ],
    "minute": [
        "haib"
    ],
    "second": [
        "ǀgâub"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "neetsee"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "mn",
    "date_order": "YMD",
    "january": [
        "нэгдүгээр сар",
        "1-р сар"
    ],
    "february": [
        "хоёрдугаар сар",
        "2-р сар"
    ],
    "march": [
        "гуравдугаар сар",
        "3-р сар"
    ],
    "april": [
        "дөрөвдүгээр сар",
        "4-р сар"
    ],
    "may": [
        "тавдугаар сар",
        "5-р сар"
    ],
    "june": [
        "зургадугаар сар",
        "6-р сар"
    ],
    "july": [
        "долдугаар сар",
        "7-р сар"
    ],
    "august": [
        "наймдугаар сар",
        "8-р сар"
    ],
    "september": [
        "есдүгээр сар",
        "9-р сар"
    ],
    "october": [
        "аравдугаар сар",
        "10-р сар"
    ],
    "november": [
        "арван нэгдүгээр сар",
        "11-р сар"
    ],
    "december": [
        "арван хоёрдугаар сар",
        "12-р сар"
    ],
    "monday": [
        "даваа",
        "да"
    ],
    "tuesday": [
        "мягмар",
        "мя"
    ],
    "wednesday": [
        "лхагва",
        "лх"
    ],
    "thursday": [
        "пүрэв",
        "пү"
    ],
    "friday": [
        "баасан",
        "ба"
    ],
    "saturday": [
        "бямба",
        "бя"
    ],
    "sunday": [
        "ням",
        "ня"
    ],
    "am": [
        "үө"
    ],
    "pm": [
        "үх"
    ],
    "year": [
        "жил"
    ],
    "month": [
        "сар"
    ],
    "week": [
        "долоо хоног",
        "7х"
    ],
    "day": [
        "өдөр"
    ],
    "hour": [
        "цаг",
        "ц"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "өнгөрсөн жил"
        ],
        "0 year ago": [
            "энэ жил"
        ],
        "in 1 year": [
            "ирэх жил"
        ],
        "1 month ago": [
            "өнгөрсөн сар"
        ],
        "0 month ago": [
            "энэ сар"
        ],
        "in 1 month": [
            "ирэх сар"
        ],
        "1 week ago": [
            "өнгөрсөн долоо хоног"
        ],
        "0 week ago": [
            "энэ долоо хоног"
        ],
        "in 1 week": [
            "ирэх долоо хоног"
        ],
        "1 day ago": [
            "өчигдөр"
        ],
        "0 day ago": [
            "өнөөдөр"
        ],
        "in 1 day": [
            "маргааш"
        ],
        "0 hour ago": [
            "энэ цаг"
        ],
        "0 minute ago": [
            "энэ минут"
        ],
        "0 second ago": [
            "одоо"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жилийн дараа"
        ],
        "\\1 year ago": [
            "(\\d+) жилийн өмнө"
        ],
        "in \\1 month": [
            "(\\d+) сарын дараа"
        ],
        "\\1 month ago": [
            "(\\d+) сарын өмнө"
        ],
        "in \\1 week": [
            "(\\d+) 7х-ийн дараа"
        ],
        "\\1 week ago": [
            "(\\d+) 7х-ийн өмнө"
        ],
        "in \\1 day": [
            "(\\d+) өдрийн дараа",
            "(\\d+) өдөрт"
        ],
        "\\1 day ago": [
            "(\\d+) өдрийн өмнө"
        ],
        "in \\1 hour": [
            "(\\d+) цагийн дараа",
            "(\\d+) ц дараа"
        ],
        "\\1 hour ago": [
            "(\\d+) цагийн өмнө",
            "(\\d+) ц өмнө"
        ],
        "in \\1 minute": [
            "(\\d+) минутын дараа",
            "(\\d+) мин дараа"
        ],
        "\\1 minute ago": [
            "(\\d+) минутын өмнө",
            "(\\d+) мин өмнө"
        ],
        "in \\1 second": [
            "(\\d+) секундын дараа",
            "(\\d+) сек дараа"
        ],
        "\\1 second ago": [
            "(\\d+) секундын өмнө",
            "(\\d+) сек өмнө"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "mfe",
    "date_order": "DMY",
    "january": [
        "zanvie",
        "zan"
    ],
    "february": [
        "fevriye",
        "fev"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "avril",
        "avr"
    ],
    "may": [
        "me"
    ],
    "june": [
        "zin"
    ],
    "july": [
        "zilye",
        "zil"
    ],
    "august": [
        "out"
    ],
    "september": [
        "septam",
        "sep"
    ],
    "october": [
        "oktob",
        "okt"
    ],
    "november": [
        "novam",
        "nov"
    ],
    "december": [
        "desam",
        "des"
    ],
    "monday": [
        "lindi",
        "lin"
    ],
    "tuesday": [
        "mardi",
        "mar"
    ],
    "wednesday": [
        "merkredi",
        "mer"
    ],
    "thursday": [
        "zedi",
        "ze"
    ],
    "friday": [
        "vandredi",
        "van"
    ],
    "saturday": [
        "samdi",
        "sam"
    ],
    "sunday": [
        "dimans",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "lane"
    ],
    "month": [
        "mwa"
    ],
    "week": [
        "semenn"
    ],
    "day": [
        "zour"
    ],
    "hour": [
        "ler"
    ],
    "minute": [
        "minit"
    ],
    "second": [
        "segonn"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yer"
        ],
        "0 day ago": [
            "zordi"
        ],
        "in 1 day": [
            "demin"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "dyo",
    "date_order": "DMY",
    "january": [
        "sanvie",
        "sa"
    ],
    "february": [
        "fébirie",
        "fe"
    ],
    "march": [
        "mars",
        "ma"
    ],
    "april": [
        "aburil",
        "ab"
    ],
    "may": [
        "mee",
        "me"
    ],
    "june": [
        "sueŋ",
        "su"
    ],
    "july": [
        "súuyee",
        "sú"
    ],
    "august": [
        "ut"
    ],
    "september": [
        "settembar",
        "se"
    ],
    "october": [
        "oktobar",
        "ok"
    ],
    "november": [
        "novembar",
        "no"
    ],
    "december": [
        "disambar",
        "de"
    ],
    "monday": [
        "teneŋ",
        "ten"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "alarbay",
        "ala"
    ],
    "thursday": [
        "aramisay",
        "ara"
    ],
    "friday": [
        "arjuma",
        "arj"
    ],
    "saturday": [
        "sibiti",
        "sib"
    ],
    "sunday": [
        "dimas",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "emit"
    ],
    "month": [
        "fuleeŋ"
    ],
    "week": [
        "lóokuŋ"
    ],
    "day": [
        "funak"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "fucen"
        ],
        "0 day ago": [
            "jaat"
        ],
        "in 1 day": [
            "kajom"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "shi-Latn",
    "date_order": "DMY",
    "january": [
        "innayr",
        "inn"
    ],
    "february": [
        "bṛayṛ",
        "bṛa"
    ],
    "march": [
        "maṛṣ",
        "maṛ"
    ],
    "april": [
        "ibrir",
        "ibr"
    ],
    "may": [
        "mayyu",
        "may"
    ],
    "june": [
        "yunyu",
        "yun"
    ],
    "july": [
        "yulyuz",
        "yul"
    ],
    "august": [
        "ɣuct",
        "ɣuc"
    ],
    "september": [
        "cutanbir",
        "cut"
    ],
    "october": [
        "ktubr",
        "ktu"
    ],
    "november": [
        "nuwanbir",
        "nuw"
    ],
    "december": [
        "dujanbir",
        "duj"
    ],
    "monday": [
        "aynas",
        "ayn"
    ],
    "tuesday": [
        "asinas",
        "asi"
    ],
    "wednesday": [
        "akṛas",
        "akṛ"
    ],
    "thursday": [
        "akwas",
        "akw"
    ],
    "friday": [
        "asimwas",
        "asim"
    ],
    "saturday": [
        "asiḍyas",
        "asiḍ"
    ],
    "sunday": [
        "asamas",
        "asa"
    ],
    "am": [
        "tifawt"
    ],
    "pm": [
        "tadggʷat"
    ],
    "year": [
        "asggʷas"
    ],
    "month": [
        "ayyur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdidt"
    ],
    "second": [
        "tasint"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "iḍlli"
        ],
        "0 day ago": [
            "assa"
        ],
        "in 1 day": [
            "askka"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "%%spellout-cardinal-feminine-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-feminine=;"
    },
    "%%spellout-cardinal-genitive-tens": {
        "1": "dziesięciu;",
        "2": "dwudziestu;",
        "3": "trzydziestu;",
        "4": "czterdziestu;",
        "5": "pięćdziesięciu;",
        "6": "sześćdziesięciu;",
        "7": "siedemdziesięciu;",
        "8": "osiemdziesięciu;",
        "(9, 'inf')": "dziewięćdziesięciu;"
    },
    "%%spellout-cardinal-masculine-dative-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%%spellout-cardinal-masculine-genitive-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%%spellout-cardinal-masculine-instrumental-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%%spellout-cardinal-masculine-locative-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%%spellout-cardinal-tens": {
        "1": "dziesięć;",
        "2": "dwadzieścia;",
        "3": "trzydzieści;",
        "4": "czterdzieści;",
        "5": "pięćdziesiąt;",
        "6": "sześćdziesiąt;",
        "7": "siedemdziesiąt;",
        "8": "osiemdziesiąt;",
        "(9, 'inf')": "dziewięćdziesiąt;"
    },
    "%%spellout-fraction": {
        "(10, 99)": "<%spellout-cardinal-masculine<<;",
        "(100, 999)": "<%spellout-cardinal-masculine<<;",
        "(1000, 9999)": "<%spellout-cardinal-masculine<<;",
        "(10000, 99999)": "<%%spellout-fraction-digits<<;",
        "(100000, 999999)": "<%%spellout-fraction-digits<<;",
        "(1000000, 9999999)": "<%%spellout-fraction-digits<<;",
        "(10000000, 99999999)": "<%%spellout-fraction-digits<<;",
        "(100000000, 999999999)": "<%%spellout-fraction-digits<<;",
        "(1000000000, 9999999999)": "<%%spellout-fraction-digits<<;",
        "(10000000000, 'inf')": "<0<;"
    },
    "%%spellout-fraction-digits": {
        "(0, 9)": "=%spellout-cardinal-masculine=;",
        "(10, 'inf')": "<< >>;"
    },
    "%spellout-cardinal-feminine": {
        "0": "zero;",
        "1": "jedna;",
        "2": "dwie;",
        "3": "trzy;",
        "4": "cztery;",
        "5": "pięć;",
        "6": "sześć;",
        "7": "siedem;",
        "8": "osiem;",
        "9": "dziewięć;",
        "10": "dziesięć;",
        "11": "jedenaście;",
        "12": "dwanaście;",
        "13": "trzynaście;",
        "14": "czternaście;",
        "15": "piętnaście;",
        "16": "szesnaście;",
        "17": "siedemnaście;",
        "18": "osiemnaście;",
        "19": "dziewiętnaście;",
        "(20, 99)": "<%%spellout-cardinal-tens<[ >%%spellout-cardinal-feminine-ones>];",
        "(100, 199)": "sto[ >%%spellout-cardinal-feminine-ones>];",
        "(200, 299)": "dwieście[ >%%spellout-cardinal-feminine-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<sta[ >%%spellout-cardinal-feminine-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine<set[ >%%spellout-cardinal-feminine-ones>];",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-feminine-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000, 1999999)": "milion[ >%%spellout-cardinal-feminine-ones>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-accusative": {
        "0": "zero;",
        "1": "jedną;",
        "(2, 'inf')": "=%spellout-cardinal-feminine=;"
    },
    "%spellout-cardinal-feminine-dative": {
        "0": "zeru;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-feminine-genitive": {
        "0": "zera;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-feminine-instrumental": {
        "0": "zerem;",
        "1": "jedną;",
        "2": "dwiema;",
        "(3, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%spellout-cardinal-feminine-locative": {
        "0": "zerze;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "zero;",
        "1": "jeden;",
        "2": "dwa;",
        "3": "trzy;",
        "4": "cztery;",
        "5": "pięć;",
        "6": "sześć;",
        "7": "siedem;",
        "8": "osiem;",
        "9": "dziewięć;",
        "10": "dziesięć;",
        "11": "jedenaście;",
        "12": "dwanaście;",
        "13": "trzynaście;",
        "14": "czternaście;",
        "15": "piętnaście;",
        "16": "szesnaście;",
        "17": "siedemnaście;",
        "18": "osiemnaście;",
        "19": "dziewiętnaście;",
        "(20, 99)": "<%%spellout-cardinal-tens<[ >>];",
        "(100, 199)": "sto[ >>];",
        "(200, 299)": "dwieście[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<sta[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<set[ >>];",
        "(1000, 1999)": "tysiąc[ >>];",
        "(2000, 999999)": "<< $(cardinal,few{tysiące}other{tysięcy})$[ >>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >>];",
        "(2000000000000000, 999999999999999999)": "<< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-accusative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-masculine-accusative-animate": {
        "0": "zero;",
        "1": "jednego;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-masculine-accusative-personal": {
        "(0, 999)": "=%spellout-cardinal-masculine-genitive=;",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-dative": {
        "0": "zeru;",
        "1": "jednemu;",
        "2": "dwóm;",
        "3": "trzem;",
        "4": "czterem;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000, 1999)": "tysiącowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000, 999999)": "<< tysiącom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000, 1999999)": "milionowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000, 999999999)": "<< milionom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000, 1999999999)": "miliardowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000, 999999999999)": "<< miliardom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000, 1999999999999)": "bilionowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-genitive": {
        "0": "zera;",
        "1": "jednego;",
        "2": "dwóch;",
        "3": "trzech;",
        "4": "czterech;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000, 1999)": "tysiąca[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<< tysięcy[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "miliona[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000, 999999999)": "<< milionów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000, 1999999999)": "miliarda[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000, 999999999999)": "<< miliardów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000, 1999999999999)": "biliona[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000000, 1999999999999999)": "biliarda[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-instrumental": {
        "0": "zerem;",
        "1": "jednym;",
        "2": "dwoma;",
        "3": "trzema;",
        "4": "czterema;",
        "5": "pięcioma;",
        "6": "sześcioma;",
        "7": "siedmioma;",
        "8": "ośmioma;",
        "9": "dziewięcioma;",
        "10": "dziesięcioma;",
        "11": "jedenastoma;",
        "12": "dwunastoma;",
        "13": "trzynastoma;",
        "14": "czternastoma;",
        "15": "piętnastoma;",
        "16": "szesnastoma;",
        "17": "siedemnastoma;",
        "18": "osiemnastoma;",
        "19": "dziewiętnastoma;",
        "(20, 29)": "dwudziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(30, 39)": "trzydziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(40, 49)": "czterdziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(50, 59)": "pięćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(60, 69)": "sześćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(70, 79)": "siedemdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(80, 89)": "osiemdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(90, 99)": "dziewięćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000, 1999)": "tysiącem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000, 999999)": "<< tysiącami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000, 1999999)": "milionem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000, 999999999)": "<< milionami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000, 1999999999)": "miliardem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000, 999999999999)": "<< miliardami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000, 1999999999999)": "bilionem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-locative": {
        "0": "zerze;",
        "1": "jednym;",
        "2": "dwóch;",
        "3": "trzech;",
        "4": "czterech;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000, 1999)": "tysiącu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000, 999999)": "<< tysiącach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000, 1999999)": "milionie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000, 999999999)": "<< milionach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000, 1999999999)": "miliardzie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000, 999999999999)": "<< miliardach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000, 1999999999999)": "bilionie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardzie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-personal": {
        "0": "zero;",
        "1": "jeden;",
        "2": "dwaj;",
        "3": "trzej;",
        "4": "czterej;",
        "(5, 999)": "=%spellout-cardinal-masculine-genitive=;",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter": {
        "0": "zero;",
        "1": "jedno;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-neuter-accusative": {
        "0": "zero;",
        "1": "jedno;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-neuter-instrumental": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%spellout-cardinal-neuter-locative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-numbering=;"
    }
}


# -*- coding: utf-8 -*-
info = {
    "name": "uk",
    "date_order": "DMY",
    "january": [
        "січень",
        "січ",
        "січня"
    ],
    "february": [
        "лютий",
        "лют",
        "лютого"
    ],
    "march": [
        "березень",
        "бер",
        "березня"
    ],
    "april": [
        "квітень",
        "кві",
        "квітня",
        "квіт"
    ],
    "may": [
        "травень",
        "тра",
        "травня",
        "трав"
    ],
    "june": [
        "червень",
        "чер",
        "червня",
        "черв"
    ],
    "july": [
        "липень",
        "лип",
        "липня"
    ],
    "august": [
        "серпень",
        "сер",
        "серпня",
        "серп"
    ],
    "september": [
        "вересень",
        "вер",
        "вересня"
    ],
    "october": [
        "жовтень",
        "жов",
        "жовтня",
        "жовт"
    ],
    "november": [
        "листопад",
        "лис",
        "листопада",
        "лист"
    ],
    "december": [
        "грудень",
        "гру",
        "грудня",
        "груд"
    ],
    "monday": [
        "понеділок",
        "пн",
        "пон"
    ],
    "tuesday": [
        "вівторок",
        "вт",
        "вів"
    ],
    "wednesday": [
        "середа",
        "ср"
    ],
    "thursday": [
        "четвер",
        "чт",
        "чет"
    ],
    "friday": [
        "п'ятниця",
        "пт"
    ],
    "saturday": [
        "субота",
        "сб",
        "суб"
    ],
    "sunday": [
        "неділя",
        "нд",
        "нед"
    ],
    "am": [
        "дп"
    ],
    "pm": [
        "пп"
    ],
    "year": [
        "рік",
        "р",
        "роки",
        "років"
    ],
    "month": [
        "місяць",
        "міс",
        "місяці",
        "місяців"
    ],
    "week": [
        "тиждень",
        "тиж",
        "тижні",
        "тижнів"
    ],
    "day": [
        "день",
        "д",
        "дні",
        "днів"
    ],
    "hour": [
        "година",
        "год",
        "години",
        "годин",
        "годину",
        "г"
    ],
    "minute": [
        "хвилина",
        "хв",
        "хвилини",
        "хвилин",
        "хвилину"
    ],
    "second": [
        "секунда",
        "с",
        "секунди",
        "секунд",
        "секунду",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "торік"
        ],
        "0 year ago": [
            "цього року"
        ],
        "in 1 year": [
            "наступного року"
        ],
        "1 month ago": [
            "минулого місяця"
        ],
        "0 month ago": [
            "цього місяця"
        ],
        "in 1 month": [
            "наступного місяця"
        ],
        "1 week ago": [
            "минулого тижня"
        ],
        "0 week ago": [
            "цього тижня"
        ],
        "in 1 week": [
            "наступного тижня"
        ],
        "1 day ago": [
            "учора",
            "вчора"
        ],
        "0 day ago": [
            "сьогодні"
        ],
        "in 1 day": [
            "завтра"
        ],
        "0 hour ago": [
            "цієї години"
        ],
        "0 minute ago": [
            "цієї хвилини"
        ],
        "0 second ago": [
            "зараз"
        ],
        "2 day ago": [
            "позавчора"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "через (\\d+) рік",
            "через (\\d+) року",
            "через (\\d+) р",
            "за (\\d+) р"
        ],
        "\\1 year ago": [
            "(\\d+) рік тому",
            "(\\d+) року тому",
            "(\\d+) р тому"
        ],
        "in \\1 month": [
            "через (\\d+) місяць",
            "через (\\d+) місяця",
            "через (\\d+) міс",
            "за (\\d+) міс"
        ],
        "\\1 month ago": [
            "(\\d+) місяць тому",
            "(\\d+) місяця тому",
            "(\\d+) міс тому"
        ],
        "in \\1 week": [
            "через (\\d+) тиждень",
            "через (\\d+) тижня",
            "через (\\d+) тиж",
            "за (\\d+) тиж"
        ],
        "\\1 week ago": [
            "(\\d+) тиждень тому",
            "(\\d+) тижня тому",
            "(\\d+) тиж тому"
        ],
        "in \\1 day": [
            "через (\\d+) день",
            "через (\\d+) дня",
            "через (\\d+) дн",
            "за (\\d+) д"
        ],
        "\\1 day ago": [
            "(\\d+) день тому",
            "(\\d+) дня тому",
            "(\\d+) дн тому",
            "(\\d+) д тому"
        ],
        "in \\1 hour": [
            "через (\\d+) годину",
            "через (\\d+) години",
            "через (\\d+) год",
            "за (\\d+) год"
        ],
        "\\1 hour ago": [
            "(\\d+) годину тому",
            "(\\d+) години тому",
            "(\\d+) год тому"
        ],
        "in \\1 minute": [
            "через (\\d+) хвилину",
            "через (\\d+) хвилини",
            "через (\\d+) хв",
            "за (\\d+) хв"
        ],
        "\\1 minute ago": [
            "(\\d+) хвилину тому",
            "(\\d+) хвилини тому",
            "(\\d+) хв тому"
        ],
        "in \\1 second": [
            "через (\\d+) секунду",
            "через (\\d+) секунди",
            "через (\\d+) с",
            "за (\\d+) с"
        ],
        "\\1 second ago": [
            "(\\d+) секунду тому",
            "(\\d+) секунди тому",
            "(\\d+) с тому"
        ]
    },
    "locale_specific": {},
    "skip": [
        "близько",
        "о",
        "об",
        "і",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "тому",
        "назад"
    ],
    "in": [
        "протягом"
    ],
    "simplifications": [
        {
            "^година": "1 година"
        },
        {
            "^годину": "1 годину"
        },
        {
            "^хвилину": "1 хвилину"
        },
        {
            "^секунду": "1 секунду"
        },
        {
            "кілька секунд": "44 секунди"
        },
        {
            "кілька хвилин": "2 хвилини"
        },
        {
            "опів на": "30 хвилин"
        },
        {
            "за чверть": "15 хвилин"
        }
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "fo",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "apríl",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mánadagur",
        "mán"
    ],
    "tuesday": [
        "týsdagur",
        "týs"
    ],
    "wednesday": [
        "mikudagur",
        "mik"
    ],
    "thursday": [
        "hósdagur",
        "hós"
    ],
    "friday": [
        "fríggjadagur",
        "frí"
    ],
    "saturday": [
        "leygardagur",
        "ley"
    ],
    "sunday": [
        "sunnudagur",
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ár"
    ],
    "month": [
        "mánaður",
        "mnð"
    ],
    "week": [
        "vika",
        "vi",
        "v"
    ],
    "day": [
        "dagur",
        "da",
        "d"
    ],
    "hour": [
        "tími",
        "t"
    ],
    "minute": [
        "minuttur",
        "min",
        "m"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "í fjør"
        ],
        "0 year ago": [
            "í ár"
        ],
        "in 1 year": [
            "næsta ár"
        ],
        "1 month ago": [
            "seinasta mánað"
        ],
        "0 month ago": [
            "henda mánaðin"
        ],
        "in 1 month": [
            "næsta mánað"
        ],
        "1 week ago": [
            "seinastu viku"
        ],
        "0 week ago": [
            "hesu viku"
        ],
        "in 1 week": [
            "næstu viku"
        ],
        "1 day ago": [
            "í gjár"
        ],
        "0 day ago": [
            "í dag"
        ],
        "in 1 day": [
            "í morgin"
        ],
        "0 hour ago": [
            "hendan tíman"
        ],
        "0 minute ago": [
            "hendan minuttin"
        ],
        "0 second ago": [
            "nú"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "um (\\d+) ár"
        ],
        "\\1 year ago": [
            "(\\d+) ár síðan"
        ],
        "in \\1 month": [
            "um (\\d+) mánað",
            "um (\\d+) mánaðir",
            "um (\\d+) mnð"
        ],
        "\\1 month ago": [
            "(\\d+) mánað síðan",
            "(\\d+) mánaðir síðan",
            "(\\d+) mnð síðan"
        ],
        "in \\1 week": [
            "um (\\d+) viku",
            "um (\\d+) vikur",
            "um (\\d+) vi",
            "um (\\d+) v"
        ],
        "\\1 week ago": [
            "(\\d+) vika síðan",
            "(\\d+) vikur síðan",
            "(\\d+) vi síðan",
            "(\\d+) v síðan"
        ],
        "in \\1 day": [
            "um (\\d+) dag",
            "um (\\d+) dagar",
            "um (\\d+) da",
            "um (\\d+) d"
        ],
        "\\1 day ago": [
            "(\\d+) dagur síðan",
            "(\\d+) dagar síðan",
            "(\\d+) da síðan",
            "(\\d+) d síðan"
        ],
        "in \\1 hour": [
            "um (\\d+) tíma",
            "um (\\d+) tímar",
            "um (\\d+) t"
        ],
        "\\1 hour ago": [
            "(\\d+) tími síðan",
            "(\\d+) tímar síðan",
            "(\\d+) t síðan"
        ],
        "in \\1 minute": [
            "um (\\d+) minutt",
            "um (\\d+) minuttir",
            "um (\\d+) min",
            "um (\\d+) m"
        ],
        "\\1 minute ago": [
            "(\\d+) minutt síðan",
            "(\\d+) minuttir síðan",
            "(\\d+) min síðan",
            "(\\d+) m síðan"
        ],
        "in \\1 second": [
            "um (\\d+) sekund",
            "um (\\d+) sek",
            "um (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) sekund síðan",
            "(\\d+) sek síðan",
            "(\\d+) s síðan"
        ]
    },
    "locale_specific": {
        "fo-DK": {
            "name": "fo-DK"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "af",
    "date_order": "YMD",
    "january": [
        "januarie",
        "jan"
    ],
    "february": [
        "februarie",
        "feb"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "junie",
        "jun"
    ],
    "july": [
        "julie",
        "jul"
    ],
    "august": [
        "augustus",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "maandag",
        "ma"
    ],
    "tuesday": [
        "dinsdag",
        "di"
    ],
    "wednesday": [
        "woensdag",
        "wo"
    ],
    "thursday": [
        "donderdag",
        "do"
    ],
    "friday": [
        "vrydag",
        "vr"
    ],
    "saturday": [
        "saterdag",
        "sa"
    ],
    "sunday": [
        "sondag",
        "so"
    ],
    "am": [
        "vm"
    ],
    "pm": [
        "nm"
    ],
    "year": [
        "jaar",
        "j"
    ],
    "month": [
        "maand",
        "md"
    ],
    "week": [
        "week",
        "wk"
    ],
    "day": [
        "dag",
        "d"
    ],
    "hour": [
        "uur",
        "u"
    ],
    "minute": [
        "minuut",
        "min",
        "m"
    ],
    "second": [
        "sekonde",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "verlede jaar"
        ],
        "0 year ago": [
            "hierdie jaar"
        ],
        "in 1 year": [
            "volgende jaar"
        ],
        "1 month ago": [
            "verlede maand"
        ],
        "0 month ago": [
            "vandeesmaand"
        ],
        "in 1 month": [
            "volgende maand"
        ],
        "1 week ago": [
            "verlede week"
        ],
        "0 week ago": [
            "vandeesweek"
        ],
        "in 1 week": [
            "volgende week"
        ],
        "1 day ago": [
            "gister"
        ],
        "0 day ago": [
            "vandag"
        ],
        "in 1 day": [
            "môre"
        ],
        "0 hour ago": [
            "hierdie uur"
        ],
        "0 minute ago": [
            "hierdie minuut"
        ],
        "0 second ago": [
            "nou"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "oor (\\d+) jaar"
        ],
        "\\1 year ago": [
            "(\\d+) jaar gelede"
        ],
        "in \\1 month": [
            "oor (\\d+) minuut",
            "oor (\\d+) md"
        ],
        "\\1 month ago": [
            "(\\d+) maand gelede",
            "(\\d+) maande gelede",
            "(\\d+) md gelede"
        ],
        "in \\1 week": [
            "oor (\\d+) week",
            "oor (\\d+) weke",
            "oor (\\d+) w"
        ],
        "\\1 week ago": [
            "(\\d+) week gelede",
            "(\\d+) weke gelede",
            "(\\d+) w gelede"
        ],
        "in \\1 day": [
            "oor (\\d+) minuut",
            "oor (\\d+) dag",
            "oor (\\d+) dae"
        ],
        "\\1 day ago": [
            "(\\d+) dag gelede",
            "(\\d+) dae gelede"
        ],
        "in \\1 hour": [
            "oor (\\d+) uur"
        ],
        "\\1 hour ago": [
            "(\\d+) uur gelede"
        ],
        "in \\1 minute": [
            "oor (\\d+) minuut",
            "oor (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minuut gelede",
            "(\\d+) minute gelede",
            "(\\d+) min gelede"
        ],
        "in \\1 second": [
            "oor (\\d+) sekonde",
            "oor (\\d+) sekondes",
            "oor (\\d+) sek"
        ],
        "\\1 second ago": [
            "(\\d+) sekonde gelede",
            "(\\d+) sekondes gelede",
            "(\\d+) sek gelede"
        ]
    },
    "locale_specific": {
        "af-NA": {
            "name": "af-NA"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "seh",
    "date_order": "DMY",
    "january": [
        "janeiro",
        "jan"
    ],
    "february": [
        "fevreiro",
        "fev"
    ],
    "march": [
        "marco",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio",
        "mai"
    ],
    "june": [
        "junho",
        "jun"
    ],
    "july": [
        "julho",
        "jul"
    ],
    "august": [
        "augusto",
        "aug"
    ],
    "september": [
        "setembro",
        "set"
    ],
    "october": [
        "otubro",
        "otu"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "decembro",
        "dec"
    ],
    "monday": [
        "chiposi",
        "pos"
    ],
    "tuesday": [
        "chipiri",
        "pir"
    ],
    "wednesday": [
        "chitatu",
        "tat"
    ],
    "thursday": [
        "chinai",
        "nai"
    ],
    "friday": [
        "chishanu",
        "sha"
    ],
    "saturday": [
        "sabudu",
        "sab"
    ],
    "sunday": [
        "dimingu",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "chaka"
    ],
    "month": [
        "mwezi"
    ],
    "week": [
        "week"
    ],
    "day": [
        "ntsiku"
    ],
    "hour": [
        "hora"
    ],
    "minute": [
        "minuto"
    ],
    "second": [
        "segundo"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "zuro"
        ],
        "0 day ago": [
            "lero"
        ],
        "in 1 day": [
            "manguana"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "sl",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "marec",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "junij",
        "jun"
    ],
    "july": [
        "julij",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "ponedeljek",
        "pon"
    ],
    "tuesday": [
        "torek",
        "tor"
    ],
    "wednesday": [
        "sreda",
        "sre"
    ],
    "thursday": [
        "četrtek",
        "čet"
    ],
    "friday": [
        "petek",
        "pet"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "nedelja",
        "ned"
    ],
    "am": [
        "dopoldne",
        "dop"
    ],
    "pm": [
        "popoldne",
        "pop"
    ],
    "year": [
        "leto"
    ],
    "month": [
        "mesec",
        "mes"
    ],
    "week": [
        "teden",
        "ted"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "ura",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "lani"
        ],
        "0 year ago": [
            "letos"
        ],
        "in 1 year": [
            "naslednje leto"
        ],
        "1 month ago": [
            "prejšnji mesec"
        ],
        "0 month ago": [
            "ta mesec"
        ],
        "in 1 month": [
            "naslednji mesec"
        ],
        "1 week ago": [
            "prejšnji teden"
        ],
        "0 week ago": [
            "ta teden"
        ],
        "in 1 week": [
            "naslednji teden"
        ],
        "1 day ago": [
            "včeraj"
        ],
        "0 day ago": [
            "danes"
        ],
        "in 1 day": [
            "jutri"
        ],
        "0 hour ago": [
            "v tej uri"
        ],
        "0 minute ago": [
            "to minuto"
        ],
        "0 second ago": [
            "zdaj"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "čez (\\d+) leto",
            "čez (\\d+) let"
        ],
        "\\1 year ago": [
            "pred (\\d+) letom",
            "pred (\\d+) leti"
        ],
        "in \\1 month": [
            "čez (\\d+) mesec",
            "čez (\\d+) mesecev",
            "čez (\\d+) mes"
        ],
        "\\1 month ago": [
            "pred (\\d+) mesecem",
            "pred (\\d+) meseci",
            "pred (\\d+) mes"
        ],
        "in \\1 week": [
            "čez (\\d+) teden",
            "čez (\\d+) tednov",
            "čez (\\d+) ted"
        ],
        "\\1 week ago": [
            "pred (\\d+) tednom",
            "pred (\\d+) tedni",
            "pred (\\d+) ted"
        ],
        "in \\1 day": [
            "čez (\\d+) dan",
            "čez (\\d+) dni"
        ],
        "\\1 day ago": [
            "pred (\\d+) dnevom",
            "pred (\\d+) dnevi"
        ],
        "in \\1 hour": [
            "čez (\\d+) uro",
            "čez (\\d+) ur",
            "čez (\\d+) h"
        ],
        "\\1 hour ago": [
            "pred (\\d+) uro",
            "pred (\\d+) urami",
            "pred (\\d+) h"
        ],
        "in \\1 minute": [
            "čez (\\d+) minuto",
            "čez (\\d+) minut",
            "čez (\\d+) min"
        ],
        "\\1 minute ago": [
            "pred (\\d+) minuto",
            "pred (\\d+) minutami",
            "pred (\\d+) min"
        ],
        "in \\1 second": [
            "čez (\\d+) sekundo",
            "čez (\\d+) sekund",
            "čez (\\d+) s"
        ],
        "\\1 second ago": [
            "pred (\\d+) sekundo",
            "pred (\\d+) sekundami",
            "pred (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ro",
    "date_order": "DMY",
    "january": [
        "ianuarie",
        "ian"
    ],
    "february": [
        "februarie",
        "feb",
        "Febr"
    ],
    "march": [
        "martie",
        "mar",
        "Mart"
    ],
    "april": [
        "aprilie",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "iunie",
        "iun"
    ],
    "july": [
        "iulie",
        "iul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "septembrie",
        "sept",
        "Sep"
    ],
    "october": [
        "octombrie",
        "oct"
    ],
    "november": [
        "noiembrie",
        "nov",
        "Noiem"
    ],
    "december": [
        "decembrie",
        "dec"
    ],
    "monday": [
        "luni",
        "lun"
    ],
    "tuesday": [
        "marți",
        "mar"
    ],
    "wednesday": [
        "miercuri",
        "mie",
        "Mi"
    ],
    "thursday": [
        "joi"
    ],
    "friday": [
        "vineri",
        "vin"
    ],
    "saturday": [
        "sâmbătă",
        "sâm"
    ],
    "sunday": [
        "duminică",
        "dum"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "an",
        "ani"
    ],
    "month": [
        "lună",
        "luna",
        "luni"
    ],
    "week": [
        "săptămână",
        "săpt",
        "săptămâni"
    ],
    "day": [
        "zi",
        "zile"
    ],
    "hour": [
        "oră",
        "h",
        "ore"
    ],
    "minute": [
        "minut",
        "min",
        "m",
        "minute"
    ],
    "second": [
        "secundă",
        "sec",
        "s",
        "secunde"
    ],
    "relative-type": {
        "1 year ago": [
            "anul trecut"
        ],
        "0 year ago": [
            "anul acesta"
        ],
        "in 1 year": [
            "anul viitor"
        ],
        "1 month ago": [
            "luna trecută"
        ],
        "0 month ago": [
            "luna aceasta"
        ],
        "in 1 month": [
            "luna viitoare"
        ],
        "1 week ago": [
            "săptămâna trecută"
        ],
        "0 week ago": [
            "săptămâna aceasta"
        ],
        "in 1 week": [
            "săptămâna viitoare"
        ],
        "1 day ago": [
            "ieri"
        ],
        "0 day ago": [
            "azi"
        ],
        "in 1 day": [
            "mâine"
        ],
        "0 hour ago": [
            "ora aceasta"
        ],
        "0 minute ago": [
            "minutul acesta"
        ],
        "0 second ago": [
            "acum"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "peste (\\d+) an",
            "peste (\\d+) de ani",
            "peste (\\d+) ani"
        ],
        "\\1 year ago": [
            "acum (\\d+) an",
            "acum (\\d+) de ani"
        ],
        "in \\1 month": [
            "peste (\\d+) lună",
            "peste (\\d+) de luni",
            "peste (\\d+) luni"
        ],
        "\\1 month ago": [
            "acum (\\d+) lună",
            "acum (\\d+) de luni",
            "acum (\\d+) luni"
        ],
        "in \\1 week": [
            "peste (\\d+) săptămână",
            "peste (\\d+) de săptămâni",
            "peste (\\d+) săpt"
        ],
        "\\1 week ago": [
            "acum (\\d+) săptămână",
            "acum (\\d+) de săptămâni",
            "acum (\\d+) săpt"
        ],
        "in \\1 day": [
            "peste (\\d+) zi",
            "peste (\\d+) de zile",
            "peste (\\d+) zile"
        ],
        "\\1 day ago": [
            "acum (\\d+) zi",
            "acum (\\d+) de zile",
            "acum (\\d+) zile"
        ],
        "in \\1 hour": [
            "peste (\\d+) oră",
            "peste (\\d+) de ore",
            "peste (\\d+) h"
        ],
        "\\1 hour ago": [
            "acum (\\d+) oră",
            "acum (\\d+) de ore",
            "acum (\\d+) h"
        ],
        "in \\1 minute": [
            "peste (\\d+) minut",
            "peste (\\d+) de minute",
            "peste (\\d+) min"
        ],
        "\\1 minute ago": [
            "acum (\\d+) minut",
            "acum (\\d+) de minute",
            "acum (\\d+) min"
        ],
        "in \\1 second": [
            "peste (\\d+) secundă",
            "peste (\\d+) de secunde",
            "peste (\\d+) sec"
        ],
        "\\1 second ago": [
            "acum (\\d+) secundă",
            "acum (\\d+) de secunde",
            "acum (\\d+) sec"
        ]
    },
    "locale_specific": {
        "ro-MD": {
            "name": "ro-MD"
        }
    },
    "skip": [
        "la",
        "de",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "în urmă"
    ],
    "in": [
        "în"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "sv",
    "date_order": "YMD",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "mars"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "juni",
        "Jun"
    ],
    "july": [
        "juli",
        "Jul"
    ],
    "august": [
        "augusti",
        "aug"
    ],
    "september": [
        "september",
        "sep",
        "Sept"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "måndag",
        "mån",
        "Månd"
    ],
    "tuesday": [
        "tisdag",
        "tis",
        "Tisd"
    ],
    "wednesday": [
        "onsdag",
        "ons",
        "Onsd"
    ],
    "thursday": [
        "torsdag",
        "tors",
        "Torsd"
    ],
    "friday": [
        "fredag",
        "fre",
        "Fred"
    ],
    "saturday": [
        "lördag",
        "lör",
        "Lörd"
    ],
    "sunday": [
        "söndag",
        "sön",
        "Sönd"
    ],
    "am": [
        "förmiddag",
        "fm"
    ],
    "pm": [
        "eftermiddag",
        "em"
    ],
    "year": [
        "år",
        "året"
    ],
    "month": [
        "månad",
        "m",
        "mån",
        "månader",
        "månaden"
    ],
    "week": [
        "vecka",
        "v",
        "veckor"
    ],
    "day": [
        "dag",
        "dagar"
    ],
    "hour": [
        "timme",
        "tim",
        "h",
        "timmar",
        "t"
    ],
    "minute": [
        "minut",
        "min",
        "m",
        "minuter"
    ],
    "second": [
        "sekund",
        "sek",
        "s",
        "sekunder"
    ],
    "relative-type": {
        "1 year ago": [
            "i fjol",
            "förra året"
        ],
        "0 year ago": [
            "i år"
        ],
        "in 1 year": [
            "nästa år"
        ],
        "1 month ago": [
            "förra månaden",
            "förra mån"
        ],
        "0 month ago": [
            "denna månad",
            "denna mån"
        ],
        "in 1 month": [
            "nästa månad",
            "nästa mån"
        ],
        "1 week ago": [
            "förra veckan",
            "förra v"
        ],
        "0 week ago": [
            "denna vecka",
            "denna v"
        ],
        "in 1 week": [
            "nästa vecka",
            "nästa v"
        ],
        "1 day ago": [
            "i går",
            "igår"
        ],
        "0 day ago": [
            "i dag",
            "idag"
        ],
        "in 1 day": [
            "i morgon",
            "imorgon"
        ],
        "0 hour ago": [
            "denna timme"
        ],
        "0 minute ago": [
            "denna minut"
        ],
        "0 second ago": [
            "nu"
        ],
        "2 day ago": [
            "förrgår"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "för (\\d+) år sedan",
            "−(\\d+) år"
        ],
        "in \\1 month": [
            "om (\\d+) månad",
            "om (\\d+) månader",
            "om (\\d+) mån"
        ],
        "\\1 month ago": [
            "för (\\d+) månad sedan",
            "för (\\d+) månader sedan",
            "för (\\d+) mån sedan",
            "−(\\d+) mån"
        ],
        "in \\1 week": [
            "om (\\d+) vecka",
            "om (\\d+) veckor",
            "om (\\d+) v"
        ],
        "\\1 week ago": [
            "för (\\d+) vecka sedan",
            "för (\\d+) veckor sedan",
            "för (\\d+) v sedan",
            "−(\\d+) v"
        ],
        "in \\1 day": [
            "om (\\d+) dag",
            "om (\\d+) dagar",
            "om (\\d+) d"
        ],
        "\\1 day ago": [
            "för (\\d+) dag sedan",
            "för (\\d+) dagar sedan",
            "för (\\d+) d sedan",
            "−(\\d+) d"
        ],
        "in \\1 hour": [
            "om (\\d+) timme",
            "om (\\d+) timmar",
            "om (\\d+) tim"
        ],
        "\\1 hour ago": [
            "för (\\d+) timme sedan",
            "för (\\d+) timmar sedan",
            "för (\\d+) tim sedan",
            "−(\\d+) h"
        ],
        "in \\1 minute": [
            "om (\\d+) minut",
            "om (\\d+) minuter",
            "om (\\d+) min"
        ],
        "\\1 minute ago": [
            "för (\\d+) minut sedan",
            "för (\\d+) minuter sedan",
            "för (\\d+) min sedan",
            "−(\\d+) min"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder",
            "om (\\d+) sek"
        ],
        "\\1 second ago": [
            "för (\\d+) sekund sedan",
            "för (\\d+) sekunder sedan",
            "för (\\d+) sek sedan",
            "−(\\d+) s"
        ]
    },
    "locale_specific": {
        "sv-AX": {
            "name": "sv-AX"
        },
        "sv-FI": {
            "name": "sv-FI",
            "date_order": "DMY"
        }
    },
    "skip": [
        "på",
        "den",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "sedan"
    ],
    "in": [
        "om",
        "från nu"
    ],
    "simplifications": [
        {
            "en": "1"
        },
        {
            "två": "2"
        }
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "id",
    "date_order": "DMY",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "maret",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "agustus",
        "agt",
        "Agu"
    ],
    "september": [
        "september",
        "sep",
        "Sept"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "senin",
        "sen"
    ],
    "tuesday": [
        "selasa",
        "sel"
    ],
    "wednesday": [
        "rabu",
        "rab"
    ],
    "thursday": [
        "kamis",
        "kam"
    ],
    "friday": [
        "jumat",
        "jum"
    ],
    "saturday": [
        "sabtu",
        "sab"
    ],
    "sunday": [
        "minggu",
        "min",
        "Ahad"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "tahun",
        "thn"
    ],
    "month": [
        "bulan",
        "bln"
    ],
    "week": [
        "minggu",
        "mgg"
    ],
    "day": [
        "hari",
        "h"
    ],
    "hour": [
        "jam",
        "j"
    ],
    "minute": [
        "menit",
        "mnt",
        "m"
    ],
    "second": [
        "detik",
        "dtk",
        "d"
    ],
    "relative-type": {
        "1 year ago": [
            "tahun lalu"
        ],
        "0 year ago": [
            "tahun ini"
        ],
        "in 1 year": [
            "tahun depan"
        ],
        "1 month ago": [
            "bulan lalu"
        ],
        "0 month ago": [
            "bulan ini"
        ],
        "in 1 month": [
            "bulan berikutnya"
        ],
        "1 week ago": [
            "minggu lalu"
        ],
        "0 week ago": [
            "minggu ini"
        ],
        "in 1 week": [
            "minggu depan"
        ],
        "1 day ago": [
            "kemarin"
        ],
        "0 day ago": [
            "hari ini"
        ],
        "in 1 day": [
            "besok"
        ],
        "0 hour ago": [
            "jam ini"
        ],
        "0 minute ago": [
            "menit ini"
        ],
        "0 second ago": [
            "sekarang",
            "baru saja"
        ],
        "1 year": [
            "setahun"
        ],
        "1 month": [
            "sebulan"
        ],
        "1 week": [
            "seminggu"
        ],
        "2 day ago": [
            "kemarin lusa"
        ],
        "1 day": [
            "sehari"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "dalam (\\d+) tahun",
            "dlm (\\d+) thn"
        ],
        "\\1 year ago": [
            "(\\d+) tahun yang lalu",
            "(\\d+) thn lalu"
        ],
        "in \\1 month": [
            "dalam (\\d+) bulan",
            "dlm (\\d+) bln"
        ],
        "\\1 month ago": [
            "(\\d+) bulan yang lalu",
            "(\\d+) bln lalu"
        ],
        "in \\1 week": [
            "dalam (\\d+) minggu",
            "dlm (\\d+) mgg"
        ],
        "\\1 week ago": [
            "(\\d+) minggu yang lalu",
            "(\\d+) mgg lalu"
        ],
        "in \\1 day": [
            "dalam (\\d+) hari",
            "dalam (\\d+) h"
        ],
        "\\1 day ago": [
            "(\\d+) hari yang lalu",
            "(\\d+) h lalu"
        ],
        "in \\1 hour": [
            "dalam (\\d+) jam"
        ],
        "\\1 hour ago": [
            "(\\d+) jam yang lalu",
            "(\\d+) jam lalu"
        ],
        "in \\1 minute": [
            "dalam (\\d+) menit",
            "dlm (\\d+) mnt"
        ],
        "\\1 minute ago": [
            "(\\d+) menit yang lalu",
            "(\\d+) mnt lalu"
        ],
        "in \\1 second": [
            "dalam (\\d+) detik",
            "dlm (\\d+) dtk"
        ],
        "\\1 second ago": [
            "(\\d+) detik yang lalu",
            "(\\d+) dtk lalu"
        ]
    },
    "locale_specific": {},
    "skip": [
        "tanggal",
        "pukul",
        "yang",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "lalu"
    ],
    "in": [
        "dalam"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ms",
    "date_order": "DMY",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "mac"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "ogos",
        "ogo"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "disember",
        "dis"
    ],
    "monday": [
        "isnin",
        "isn"
    ],
    "tuesday": [
        "selasa",
        "sel"
    ],
    "wednesday": [
        "rabu",
        "rab"
    ],
    "thursday": [
        "khamis",
        "kha"
    ],
    "friday": [
        "jumaat",
        "jum"
    ],
    "saturday": [
        "sabtu",
        "sab"
    ],
    "sunday": [
        "ahad",
        "ahd"
    ],
    "am": [
        "pg"
    ],
    "pm": [
        "ptg"
    ],
    "year": [
        "tahun",
        "thn"
    ],
    "month": [
        "bulan",
        "bln"
    ],
    "week": [
        "minggu",
        "mgu"
    ],
    "day": [
        "hari"
    ],
    "hour": [
        "jam"
    ],
    "minute": [
        "minit",
        "min"
    ],
    "second": [
        "saat"
    ],
    "relative-type": {
        "1 year ago": [
            "tahun lalu",
            "thn lepas"
        ],
        "0 year ago": [
            "tahun ini",
            "thn ini"
        ],
        "in 1 year": [
            "tahun depan",
            "thn depan"
        ],
        "1 month ago": [
            "bulan lalu",
            "bln lalu"
        ],
        "0 month ago": [
            "bulan ini",
            "bln ini"
        ],
        "in 1 month": [
            "bulan depan",
            "bln depan"
        ],
        "1 week ago": [
            "minggu lalu",
            "mng lepas"
        ],
        "0 week ago": [
            "minggu ini",
            "mng ini"
        ],
        "in 1 week": [
            "minggu depan",
            "mng depan"
        ],
        "1 day ago": [
            "semalam",
            "semlm"
        ],
        "0 day ago": [
            "hari ini"
        ],
        "in 1 day": [
            "esok"
        ],
        "0 hour ago": [
            "jam ini"
        ],
        "0 minute ago": [
            "pada minit ini"
        ],
        "0 second ago": [
            "sekarang"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "dalam (\\d+) saat",
            "dalam (\\d+) thn"
        ],
        "\\1 year ago": [
            "(\\d+) tahun lalu",
            "(\\d+) thn lalu"
        ],
        "in \\1 month": [
            "dalam (\\d+) bulan",
            "dlm (\\d+) bln"
        ],
        "\\1 month ago": [
            "(\\d+) bulan lalu",
            "(\\d+) bln lalu"
        ],
        "in \\1 week": [
            "dalam (\\d+) minggu",
            "dlm (\\d+) mgu"
        ],
        "\\1 week ago": [
            "(\\d+) minggu lalu",
            "(\\d+) mgu lalu"
        ],
        "in \\1 day": [
            "dalam (\\d+) hari",
            "dlm (\\d+) hari"
        ],
        "\\1 day ago": [
            "(\\d+) hari lalu"
        ],
        "in \\1 hour": [
            "dalam (\\d+) jam",
            "dlm (\\d+) jam"
        ],
        "\\1 hour ago": [
            "(\\d+) jam lalu"
        ],
        "in \\1 minute": [
            "dalam (\\d+) minit",
            "dlm (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minit lalu",
            "(\\d+) min lalu"
        ],
        "in \\1 second": [
            "dalam (\\d+) saat",
            "dlm (\\d+) saat"
        ],
        "\\1 second ago": [
            "(\\d+) saat lalu"
        ]
    },
    "locale_specific": {
        "ms-SG": {
            "name": "ms-SG"
        },
        "ms-BN": {
            "name": "ms-BN"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "sq",
    "date_order": "DMY",
    "january": [
        "janar",
        "jan"
    ],
    "february": [
        "shkurt",
        "shk"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "prill",
        "pri"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "qershor",
        "qer"
    ],
    "july": [
        "korrik",
        "kor"
    ],
    "august": [
        "gusht",
        "gsh"
    ],
    "september": [
        "shtator",
        "sht"
    ],
    "october": [
        "tetor",
        "tet"
    ],
    "november": [
        "nëntor",
        "nën"
    ],
    "december": [
        "dhjetor",
        "dhj"
    ],
    "monday": [
        "e hënë",
        "hën"
    ],
    "tuesday": [
        "e martë",
        "mar"
    ],
    "wednesday": [
        "e mërkurë",
        "mër"
    ],
    "thursday": [
        "e enjte",
        "enj"
    ],
    "friday": [
        "e premte",
        "pre"
    ],
    "saturday": [
        "e shtunë",
        "sht"
    ],
    "sunday": [
        "e diel",
        "die"
    ],
    "am": [
        "paradite",
        "e paradites"
    ],
    "pm": [
        "pasdite",
        "e pasdites"
    ],
    "year": [
        "vit"
    ],
    "month": [
        "muaj"
    ],
    "week": [
        "javë"
    ],
    "day": [
        "ditë"
    ],
    "hour": [
        "orë"
    ],
    "minute": [
        "minutë",
        "min"
    ],
    "second": [
        "sekondë",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "vitin e kaluar"
        ],
        "0 year ago": [
            "këtë vit"
        ],
        "in 1 year": [
            "vitin e ardhshëm"
        ],
        "1 month ago": [
            "muajin e kaluar"
        ],
        "0 month ago": [
            "këtë muaj"
        ],
        "in 1 month": [
            "muajin e ardhshëm"
        ],
        "1 week ago": [
            "javën e kaluar"
        ],
        "0 week ago": [
            "këtë javë"
        ],
        "in 1 week": [
            "javën e ardhshme"
        ],
        "1 day ago": [
            "dje"
        ],
        "0 day ago": [
            "sot"
        ],
        "in 1 day": [
            "nesër"
        ],
        "0 hour ago": [
            "këtë orë"
        ],
        "0 minute ago": [
            "këtë minutë"
        ],
        "0 second ago": [
            "tani"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "pas (\\d+) viti",
            "pas (\\d+) vjetësh"
        ],
        "\\1 year ago": [
            "(\\d+) vit më parë",
            "(\\d+) vjet më parë"
        ],
        "in \\1 month": [
            "pas (\\d+) muaji",
            "pas (\\d+) muajsh"
        ],
        "\\1 month ago": [
            "(\\d+) muaj më parë"
        ],
        "in \\1 week": [
            "pas (\\d+) jave",
            "pas (\\d+) javësh"
        ],
        "\\1 week ago": [
            "(\\d+) javë më parë"
        ],
        "in \\1 day": [
            "pas (\\d+) dite",
            "pas (\\d+) ditësh"
        ],
        "\\1 day ago": [
            "(\\d+) ditë më parë"
        ],
        "in \\1 hour": [
            "pas (\\d+) ore",
            "pas (\\d+) orësh"
        ],
        "\\1 hour ago": [
            "(\\d+) orë më parë"
        ],
        "in \\1 minute": [
            "pas (\\d+) minute",
            "pas (\\d+) minutash",
            "pas (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minutë më parë",
            "(\\d+) minuta më parë",
            "(\\d+) min më parë"
        ],
        "in \\1 second": [
            "pas (\\d+) sekonde",
            "pas (\\d+) sekondash",
            "pas (\\d+) sek"
        ],
        "\\1 second ago": [
            "(\\d+) sekondë më parë",
            "(\\d+) sekonda më parë",
            "(\\d+) sek më parë"
        ]
    },
    "locale_specific": {
        "sq-MK": {
            "name": "sq-MK"
        },
        "sq-XK": {
            "name": "sq-XK"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ksb",
    "date_order": "DMY",
    "january": [
        "januali",
        "jan"
    ],
    "february": [
        "febluali",
        "feb"
    ],
    "march": [
        "machi",
        "mac"
    ],
    "april": [
        "aplili",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "agosti",
        "ago"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "desemba",
        "des"
    ],
    "monday": [
        "jumaatatu",
        "jtt"
    ],
    "tuesday": [
        "jumaane",
        "jmn"
    ],
    "wednesday": [
        "jumaatano",
        "jtn"
    ],
    "thursday": [
        "alhamisi",
        "alh"
    ],
    "friday": [
        "ijumaa",
        "iju"
    ],
    "saturday": [
        "jumaamosi",
        "jmo"
    ],
    "sunday": [
        "jumaapii",
        "jpi"
    ],
    "am": [
        "makeo"
    ],
    "pm": [
        "nyiaghuo"
    ],
    "year": [
        "ng'waka"
    ],
    "month": [
        "ng'ezi"
    ],
    "week": [
        "niki"
    ],
    "day": [
        "siku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ghuo"
        ],
        "0 day ago": [
            "evi eo"
        ],
        "in 1 day": [
            "keloi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "de",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "märz",
        "mär"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "dezember",
        "dez"
    ],
    "monday": [
        "montag",
        "mo",
        "Mon"
    ],
    "tuesday": [
        "dienstag",
        "di",
        "Die"
    ],
    "wednesday": [
        "mittwoch",
        "mi",
        "Mit"
    ],
    "thursday": [
        "donnerstag",
        "do",
        "Don"
    ],
    "friday": [
        "freitag",
        "fr",
        "Fre"
    ],
    "saturday": [
        "samstag",
        "sa",
        "Sam"
    ],
    "sunday": [
        "sonntag",
        "so",
        "Son"
    ],
    "am": [
        "vorm"
    ],
    "pm": [
        "nachm"
    ],
    "year": [
        "jahr",
        "j",
        "Jahre"
    ],
    "month": [
        "monat",
        "m",
        "Monate",
        "Monaten"
    ],
    "week": [
        "woche",
        "w",
        "Wochen"
    ],
    "day": [
        "tag",
        "Tage"
    ],
    "hour": [
        "stunde",
        "std",
        "Stunden"
    ],
    "minute": [
        "minute",
        "min",
        "Minuten"
    ],
    "second": [
        "sekunde",
        "sek",
        "Sekunden"
    ],
    "relative-type": {
        "1 year ago": [
            "letztes jahr"
        ],
        "0 year ago": [
            "dieses jahr"
        ],
        "in 1 year": [
            "nächstes jahr"
        ],
        "1 month ago": [
            "letzten monat"
        ],
        "0 month ago": [
            "diesen monat"
        ],
        "in 1 month": [
            "nächsten monat"
        ],
        "1 week ago": [
            "letzte woche"
        ],
        "0 week ago": [
            "diese woche"
        ],
        "in 1 week": [
            "nächste woche"
        ],
        "1 day ago": [
            "gestern"
        ],
        "0 day ago": [
            "heute"
        ],
        "in 1 day": [
            "morgen"
        ],
        "0 hour ago": [
            "in dieser stunde"
        ],
        "0 minute ago": [
            "in dieser minute"
        ],
        "0 second ago": [
            "jetzt"
        ],
        "2 day ago": [
            "vorgestern"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "in (\\d+) jahr",
            "in (\\d+) jahren"
        ],
        "\\1 year ago": [
            "vor (\\d+) jahr",
            "vor (\\d+) jahren"
        ],
        "in \\1 month": [
            "in (\\d+) monat",
            "in (\\d+) monaten"
        ],
        "\\1 month ago": [
            "vor (\\d+) monat",
            "vor (\\d+) monaten"
        ],
        "in \\1 week": [
            "in (\\d+) woche",
            "in (\\d+) wochen",
            "in (\\d+) wo"
        ],
        "\\1 week ago": [
            "vor (\\d+) woche",
            "vor (\\d+) wochen",
            "vor (\\d+) wo"
        ],
        "in \\1 day": [
            "in (\\d+) tag",
            "in (\\d+) tagen"
        ],
        "\\1 day ago": [
            "vor (\\d+) tag",
            "vor (\\d+) tagen"
        ],
        "in \\1 hour": [
            "in (\\d+) stunde",
            "in (\\d+) stunden",
            "in (\\d+) std"
        ],
        "\\1 hour ago": [
            "vor (\\d+) stunde",
            "vor (\\d+) stunden",
            "vor (\\d+) std",
            "vor (\\d+)\\s*h"
        ],
        "in \\1 minute": [
            "in (\\d+) minute",
            "in (\\d+) minuten",
            "in (\\d+) min",
            "in (\\d+) m"
        ],
        "\\1 minute ago": [
            "vor (\\d+) minute",
            "vor (\\d+) minuten",
            "vor (\\d+) min",
            "vor (\\d+) m",
            "vor (\\d+)\\s*m"
        ],
        "in \\1 second": [
            "in (\\d+) sekunde",
            "in (\\d+) sekunden",
            "in (\\d+) sek",
            "in (\\d+) s"
        ],
        "\\1 second ago": [
            "vor (\\d+) sekunde",
            "vor (\\d+) sekunden",
            "vor (\\d+) sek",
            "vor (\\d+) s",
            "vor (\\d+)\\s*s"
        ]
    },
    "locale_specific": {
        "de-LU": {
            "name": "de-LU"
        },
        "de-AT": {
            "name": "de-AT",
            "january": [
                "jänner",
                "jän"
            ]
        },
        "de-CH": {
            "name": "de-CH"
        },
        "de-LI": {
            "name": "de-LI"
        },
        "de-BE": {
            "name": "de-BE"
        },
        "de-IT": {
            "name": "de-IT",
            "january": [
                "jänner",
                "jän"
            ]
        }
    },
    "skip": [
        "um",
        "uhr",
        "etwa",
        "und",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "vor"
    ],
    "in": [
        "in",
        "im"
    ],
    "simplifications": [
        {
            "einer": "1"
        },
        {
            "einem": "1"
        }
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "mg",
    "date_order": "YMD",
    "january": [
        "janoary",
        "jan"
    ],
    "february": [
        "febroary",
        "feb"
    ],
    "march": [
        "martsa",
        "mar"
    ],
    "april": [
        "aprily",
        "apr"
    ],
    "may": [
        "mey"
    ],
    "june": [
        "jona",
        "jon"
    ],
    "july": [
        "jolay",
        "jol"
    ],
    "august": [
        "aogositra",
        "aog"
    ],
    "september": [
        "septambra",
        "sep"
    ],
    "october": [
        "oktobra",
        "okt"
    ],
    "november": [
        "novambra",
        "nov"
    ],
    "december": [
        "desambra",
        "des"
    ],
    "monday": [
        "alatsinainy",
        "alats"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "alarobia",
        "alar"
    ],
    "thursday": [
        "alakamisy",
        "alak"
    ],
    "friday": [
        "zoma",
        "zom"
    ],
    "saturday": [
        "asabotsy",
        "asab"
    ],
    "sunday": [
        "alahady",
        "alah"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taona"
    ],
    "month": [
        "volana"
    ],
    "week": [
        "herinandro"
    ],
    "day": [
        "andro"
    ],
    "hour": [
        "ora"
    ],
    "minute": [
        "minitra"
    ],
    "second": [
        "segondra"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "omaly"
        ],
        "0 day ago": [
            "anio"
        ],
        "in 1 day": [
            "rahampitso"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ff",
    "date_order": "DMY",
    "january": [
        "siilo",
        "sii"
    ],
    "february": [
        "colte",
        "col"
    ],
    "march": [
        "mbooy",
        "mbo"
    ],
    "april": [
        "seeɗto",
        "see"
    ],
    "may": [
        "duujal",
        "duu"
    ],
    "june": [
        "korse",
        "kor"
    ],
    "july": [
        "morso",
        "mor"
    ],
    "august": [
        "juko",
        "juk"
    ],
    "september": [
        "siilto",
        "slt"
    ],
    "october": [
        "yarkomaa",
        "yar"
    ],
    "november": [
        "jolal",
        "jol"
    ],
    "december": [
        "bowte",
        "bow"
    ],
    "monday": [
        "aaɓnde",
        "aaɓ"
    ],
    "tuesday": [
        "mawbaare",
        "maw"
    ],
    "wednesday": [
        "njeslaare",
        "nje"
    ],
    "thursday": [
        "naasaande",
        "naa"
    ],
    "friday": [
        "mawnde",
        "mwd"
    ],
    "saturday": [
        "hoore-biir",
        "hbi"
    ],
    "sunday": [
        "dewo",
        "dew"
    ],
    "am": [
        "subaka"
    ],
    "pm": [
        "kikiiɗe"
    ],
    "year": [
        "hitaande"
    ],
    "month": [
        "lewru"
    ],
    "week": [
        "yontere"
    ],
    "day": [
        "ñalnde"
    ],
    "hour": [
        "waktu"
    ],
    "minute": [
        "hoƴom"
    ],
    "second": [
        "majaango"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "haŋki"
        ],
        "0 day ago": [
            "hannde"
        ],
        "in 1 day": [
            "jaŋngo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "ff-GN": {
            "name": "ff-GN"
        },
        "ff-MR": {
            "name": "ff-MR"
        },
        "ff-CM": {
            "name": "ff-CM"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "br",
    "date_order": "YMD",
    "january": [
        "genver",
        "gen"
    ],
    "february": [
        "c'hwevrer",
        "c'hwe"
    ],
    "march": [
        "meurzh",
        "meur"
    ],
    "april": [
        "ebrel",
        "ebr"
    ],
    "may": [
        "mae"
    ],
    "june": [
        "mezheven",
        "mezh"
    ],
    "july": [
        "gouere",
        "goue"
    ],
    "august": [
        "eost"
    ],
    "september": [
        "gwengolo",
        "gwen"
    ],
    "october": [
        "here"
    ],
    "november": [
        "du"
    ],
    "december": [
        "kerzu",
        "ker",
        "kzu"
    ],
    "monday": [
        "lun"
    ],
    "tuesday": [
        "meurzh",
        "meu"
    ],
    "wednesday": [
        "merc'her",
        "mer"
    ],
    "thursday": [
        "yaou"
    ],
    "friday": [
        "gwener",
        "gwe"
    ],
    "saturday": [
        "sadorn",
        "sad"
    ],
    "sunday": [
        "sul"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "gm"
    ],
    "year": [
        "bloaz",
        "bl"
    ],
    "month": [
        "miz"
    ],
    "week": [
        "sizhun"
    ],
    "day": [
        "deiz",
        "d"
    ],
    "hour": [
        "eur",
        "e"
    ],
    "minute": [
        "munut",
        "min"
    ],
    "second": [
        "eilenn",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "warlene"
        ],
        "0 year ago": [
            "hevlene"
        ],
        "in 1 year": [
            "ar bloaz a zeu",
            "ar bl a zeu"
        ],
        "1 month ago": [
            "ar miz diaraok"
        ],
        "0 month ago": [
            "ar miz-mañ"
        ],
        "in 1 month": [
            "ar miz a zeu"
        ],
        "1 week ago": [
            "ar sizhun diaraok"
        ],
        "0 week ago": [
            "ar sizhun-mañ"
        ],
        "in 1 week": [
            "ar sizhun a zeu"
        ],
        "1 day ago": [
            "dec'h"
        ],
        "0 day ago": [
            "hiziv"
        ],
        "in 1 day": [
            "warc'hoazh"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "bremañ",
            "brem"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "a-benn (\\d+) bloaz",
            "a-benn (\\d+) vloaz",
            "a-benn (\\d+) bl"
        ],
        "\\1 year ago": [
            "(\\d+) bloaz zo",
            "(\\d+) vloaz zo",
            "(\\d+) bl zo"
        ],
        "in \\1 month": [
            "a-benn (\\d+) miz"
        ],
        "\\1 month ago": [
            "(\\d+) miz zo"
        ],
        "in \\1 week": [
            "a-benn (\\d+) sizhun"
        ],
        "\\1 week ago": [
            "(\\d+) sizhun zo"
        ],
        "in \\1 day": [
            "a-benn (\\d+) deiz",
            "a-benn (\\d+) d"
        ],
        "\\1 day ago": [
            "(\\d+) deiz zo",
            "(\\d+) d zo"
        ],
        "in \\1 hour": [
            "a-benn (\\d+) eur",
            "a-benn (\\d+) e"
        ],
        "\\1 hour ago": [
            "(\\d+) eur zo",
            "(\\d+) e zo"
        ],
        "in \\1 minute": [
            "a-benn (\\d+) munut",
            "a-benn (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) munut zo",
            "(\\d+) min zo"
        ],
        "in \\1 second": [
            "a-benn (\\d+) eilenn",
            "a-benn (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) eilenn zo",
            "(\\d+) s zo"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ast",
    "date_order": "DMY",
    "january": [
        "xineru",
        "xin",
        "de xineru"
    ],
    "february": [
        "febreru",
        "feb",
        "de febreru"
    ],
    "march": [
        "marzu",
        "mar",
        "de marzu"
    ],
    "april": [
        "abril",
        "abr",
        "d'abril"
    ],
    "may": [
        "mayu",
        "may",
        "de mayu"
    ],
    "june": [
        "xunu",
        "xun",
        "de xunu"
    ],
    "july": [
        "xunetu",
        "xnt",
        "de xunetu"
    ],
    "august": [
        "agostu",
        "ago",
        "d'agostu"
    ],
    "september": [
        "setiembre",
        "set",
        "de setiembre"
    ],
    "october": [
        "ochobre",
        "och",
        "d'ochobre"
    ],
    "november": [
        "payares",
        "pay",
        "de payares"
    ],
    "december": [
        "avientu",
        "avi",
        "d'avientu"
    ],
    "monday": [
        "llunes",
        "llu"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "miércoles",
        "mié"
    ],
    "thursday": [
        "xueves",
        "xue"
    ],
    "friday": [
        "vienres",
        "vie"
    ],
    "saturday": [
        "sábadu",
        "sáb"
    ],
    "sunday": [
        "domingu",
        "dom"
    ],
    "am": [
        "mañana",
        "am",
        "de la mañana"
    ],
    "pm": [
        "tarde",
        "pm",
        "de la tarde"
    ],
    "year": [
        "añu"
    ],
    "month": [
        "mes"
    ],
    "week": [
        "selmana",
        "sel"
    ],
    "day": [
        "día"
    ],
    "hour": [
        "hora",
        "h"
    ],
    "minute": [
        "minutu",
        "min",
        "m"
    ],
    "second": [
        "segundu",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "l'añu pasáu",
            "l'añu pas",
            "añu pas"
        ],
        "0 year ago": [
            "esti añu"
        ],
        "in 1 year": [
            "l'añu viniente",
            "l'añu vin",
            "añu vin"
        ],
        "1 month ago": [
            "el mes pasáu",
            "mes pas"
        ],
        "0 month ago": [
            "esti mes"
        ],
        "in 1 month": [
            "el mes viniente",
            "mes vin"
        ],
        "1 week ago": [
            "la selmana pasada",
            "selm pasada",
            "selm pas"
        ],
        "0 week ago": [
            "esta selmana",
            "esta selm"
        ],
        "in 1 week": [
            "la selmana viniente",
            "selm viniente",
            "selm vin"
        ],
        "1 day ago": [
            "ayeri"
        ],
        "0 day ago": [
            "güei"
        ],
        "in 1 day": [
            "mañana",
            "mañ"
        ],
        "0 hour ago": [
            "esta hora",
            "esta h"
        ],
        "0 minute ago": [
            "esti minutu",
            "esti min"
        ],
        "0 second ago": [
            "agora"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) añu",
            "en (\\d+) años",
            "en (\\d+) a"
        ],
        "\\1 year ago": [
            "hai (\\d+) añu",
            "hai (\\d+) años",
            "hai (\\d+) a"
        ],
        "in \\1 month": [
            "en (\\d+) mes",
            "en (\\d+) meses",
            "en (\\d+) m"
        ],
        "\\1 month ago": [
            "hai (\\d+) mes",
            "hai (\\d+) meses",
            "hai (\\d+) m"
        ],
        "in \\1 week": [
            "en (\\d+) selmana",
            "en (\\d+) selmanes",
            "en (\\d+) selm",
            "en (\\d+) se"
        ],
        "\\1 week ago": [
            "hai (\\d+) selmana",
            "hai (\\d+) selmanes",
            "hai (\\d+) selm",
            "hai (\\d+) se"
        ],
        "in \\1 day": [
            "en (\\d+) día",
            "en (\\d+) díes",
            "en (\\d+) d"
        ],
        "\\1 day ago": [
            "hai (\\d+) día",
            "hai (\\d+) díes",
            "hai (\\d+) d"
        ],
        "in \\1 hour": [
            "en (\\d+) hora",
            "en (\\d+) hores",
            "en (\\d+) h"
        ],
        "\\1 hour ago": [
            "hai (\\d+) hora",
            "hai (\\d+) hores",
            "hai (\\d+) h"
        ],
        "in \\1 minute": [
            "en (\\d+) minutu",
            "en (\\d+) minutos",
            "en (\\d+) min"
        ],
        "\\1 minute ago": [
            "hai (\\d+) minutu",
            "hai (\\d+) minutos",
            "hai (\\d+) min"
        ],
        "in \\1 second": [
            "en (\\d+) segundu",
            "en (\\d+) segundos",
            "en (\\d+) seg",
            "en (\\d+) s"
        ],
        "\\1 second ago": [
            "hai (\\d+) segundu",
            "hai (\\d+) segundos",
            "hai (\\d+) seg",
            "hai (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "fy",
    "date_order": "DMY",
    "january": [
        "jannewaris",
        "jan"
    ],
    "february": [
        "febrewaris",
        "feb"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maaie",
        "mai"
    ],
    "june": [
        "juny",
        "jun"
    ],
    "july": [
        "july",
        "jul"
    ],
    "august": [
        "augustus",
        "aug"
    ],
    "september": [
        "septimber",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "novimber",
        "nov"
    ],
    "december": [
        "desimber",
        "des"
    ],
    "monday": [
        "moandei",
        "mo"
    ],
    "tuesday": [
        "tiisdei",
        "ti"
    ],
    "wednesday": [
        "woansdei",
        "wo"
    ],
    "thursday": [
        "tongersdei",
        "to"
    ],
    "friday": [
        "freed",
        "fr"
    ],
    "saturday": [
        "sneon",
        "so"
    ],
    "sunday": [
        "snein",
        "si"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jier"
    ],
    "month": [
        "moanne"
    ],
    "week": [
        "wike"
    ],
    "day": [
        "dei"
    ],
    "hour": [
        "oere"
    ],
    "minute": [
        "minút"
    ],
    "second": [
        "sekonde"
    ],
    "relative-type": {
        "1 year ago": [
            "foarich jier"
        ],
        "0 year ago": [
            "dit jier"
        ],
        "in 1 year": [
            "folgjend jier"
        ],
        "1 month ago": [
            "foarige moanne"
        ],
        "0 month ago": [
            "dizze moanne"
        ],
        "in 1 month": [
            "folgjende moanne"
        ],
        "1 week ago": [
            "foarige wike"
        ],
        "0 week ago": [
            "dizze wike"
        ],
        "in 1 week": [
            "folgjende wike"
        ],
        "1 day ago": [
            "gisteren"
        ],
        "0 day ago": [
            "vandaag"
        ],
        "in 1 day": [
            "morgen"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "nu"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "oer (\\d+) jier"
        ],
        "\\1 year ago": [
            "(\\d+) jier lyn"
        ],
        "in \\1 month": [
            "oer (\\d+) moanne",
            "oer (\\d+) moannen"
        ],
        "\\1 month ago": [
            "(\\d+) moanne lyn",
            "(\\d+) moannen lyn"
        ],
        "in \\1 week": [
            "oer (\\d+) wike",
            "oer (\\d+) wiken"
        ],
        "\\1 week ago": [
            "(\\d+) wike lyn",
            "(\\d+) wiken lyn"
        ],
        "in \\1 day": [
            "oer (\\d+) dei",
            "oer (\\d+) deien"
        ],
        "\\1 day ago": [
            "(\\d+) dei lyn",
            "(\\d+) deien lyn"
        ],
        "in \\1 hour": [
            "oer (\\d+) oere"
        ],
        "\\1 hour ago": [
            "(\\d+) oere lyn"
        ],
        "in \\1 minute": [
            "oer (\\d+) minút",
            "oer (\\d+) minuten"
        ],
        "\\1 minute ago": [
            "(\\d+) minút lyn",
            "(\\d+) minuten lyn"
        ],
        "in \\1 second": [
            "oer (\\d+) sekonde",
            "oer (\\d+) sekonden"
        ],
        "\\1 second ago": [
            "(\\d+) sekonde lyn",
            "(\\d+) sekonden lyn"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "bem",
    "date_order": "DMY",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "machi",
        "mac"
    ],
    "april": [
        "epreo",
        "epr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "ogasti",
        "oga"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "palichimo"
    ],
    "tuesday": [
        "palichibuli"
    ],
    "wednesday": [
        "palichitatu"
    ],
    "thursday": [
        "palichine"
    ],
    "friday": [
        "palichisano"
    ],
    "saturday": [
        "pachibelushi"
    ],
    "sunday": [
        "pa mulungu"
    ],
    "am": [
        "uluchelo"
    ],
    "pm": [
        "akasuba"
    ],
    "year": [
        "umwaka"
    ],
    "month": [
        "umweshi"
    ],
    "week": [
        "umulungu"
    ],
    "day": [
        "ubushiku"
    ],
    "hour": [
        "insa"
    ],
    "minute": [
        "mineti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "lelo"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "uz-Arab",
    "date_order": "YMD",
    "january": [
        "جنوری",
        "جنو"
    ],
    "february": [
        "فبروری",
        "فبر"
    ],
    "march": [
        "مارچ",
        "مار"
    ],
    "april": [
        "اپریل",
        "اپر"
    ],
    "may": [
        "می"
    ],
    "june": [
        "جون"
    ],
    "july": [
        "جولای",
        "جول"
    ],
    "august": [
        "اگست",
        "اگس"
    ],
    "september": [
        "سپتمبر",
        "سپت"
    ],
    "october": [
        "اکتوبر",
        "اکت"
    ],
    "november": [
        "نومبر",
        "نوم"
    ],
    "december": [
        "دسمبر",
        "دسم"
    ],
    "monday": [
        "دوشنبه",
        "د"
    ],
    "tuesday": [
        "سه‌شنبه",
        "س"
    ],
    "wednesday": [
        "چهارشنبه",
        "چ"
    ],
    "thursday": [
        "پنجشنبه",
        "پ"
    ],
    "friday": [
        "جمعه",
        "ج"
    ],
    "saturday": [
        "شنبه",
        "ش"
    ],
    "sunday": [
        "یکشنبه",
        "ی"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "am",
    "date_order": "DMY",
    "january": [
        "ጃንዩወሪ",
        "ጃንዩ"
    ],
    "february": [
        "ፌብሩወሪ",
        "ፌብሩ"
    ],
    "march": [
        "ማርች"
    ],
    "april": [
        "ኤፕሪል",
        "ኤፕሪ"
    ],
    "may": [
        "ሜይ"
    ],
    "june": [
        "ጁን"
    ],
    "july": [
        "ጁላይ"
    ],
    "august": [
        "ኦገስት",
        "ኦገስ"
    ],
    "september": [
        "ሴፕቴምበር",
        "ሴፕቴ"
    ],
    "october": [
        "ኦክቶበር",
        "ኦክቶ"
    ],
    "november": [
        "ኖቬምበር",
        "ኖቬም"
    ],
    "december": [
        "ዲሴምበር",
        "ዲሴም"
    ],
    "monday": [
        "ሰኞ"
    ],
    "tuesday": [
        "ማክሰኞ",
        "ማክሰ"
    ],
    "wednesday": [
        "ረቡዕ"
    ],
    "thursday": [
        "ሐሙስ"
    ],
    "friday": [
        "ዓርብ"
    ],
    "saturday": [
        "ቅዳሜ"
    ],
    "sunday": [
        "እሑድ"
    ],
    "am": [
        "ጥዋት"
    ],
    "pm": [
        "ከሰዓት"
    ],
    "year": [
        "ዓመት"
    ],
    "month": [
        "ወር"
    ],
    "week": [
        "ሳምንት"
    ],
    "day": [
        "ቀን"
    ],
    "hour": [
        "ሰዓት"
    ],
    "minute": [
        "ደቂቃ"
    ],
    "second": [
        "ሰከንድ"
    ],
    "relative-type": {
        "1 year ago": [
            "ያለፈው ዓመት"
        ],
        "0 year ago": [
            "በዚህ ዓመት"
        ],
        "in 1 year": [
            "የሚቀጥለው ዓመት"
        ],
        "1 month ago": [
            "ያለፈው ወር"
        ],
        "0 month ago": [
            "በዚህ ወር"
        ],
        "in 1 month": [
            "የሚቀጥለው ወር"
        ],
        "1 week ago": [
            "ያለፈው ሳምንት",
            "ባለፈው ሳምንት"
        ],
        "0 week ago": [
            "በዚህ ሳምንት",
            "በዚህ ሣምንት"
        ],
        "in 1 week": [
            "የሚቀጥለው ሳምንት"
        ],
        "1 day ago": [
            "ትናንት",
            "ትላንትና"
        ],
        "0 day ago": [
            "ዛሬ"
        ],
        "in 1 day": [
            "ነገ"
        ],
        "0 hour ago": [
            "ይህ ሰዓት"
        ],
        "0 minute ago": [
            "ይህ ደቂቃ"
        ],
        "0 second ago": [
            "አሁን"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "በ(\\d+) ዓመታት ውስጥ"
        ],
        "\\1 year ago": [
            "ከ(\\d+) ዓመት በፊት",
            "ከ(\\d+) ዓመታት በፊት"
        ],
        "in \\1 month": [
            "በ(\\d+) ወር ውስጥ",
            "በ(\\d+) ወራት ውስጥ"
        ],
        "\\1 month ago": [
            "ከ(\\d+) ወር በፊት",
            "ከ(\\d+) ወራት በፊት"
        ],
        "in \\1 week": [
            "በ(\\d+) ሳምንት ውስጥ",
            "በ(\\d+) ሳምንታት ውስጥ"
        ],
        "\\1 week ago": [
            "ከ(\\d+) ሳምንት በፊት",
            "ከ(\\d+) ሳምንታት በፊት"
        ],
        "in \\1 day": [
            "በ(\\d+) ቀን ውስጥ",
            "በ(\\d+) ቀናት ውስጥ",
            "በ(\\d+) ቀኖች ውስጥ"
        ],
        "\\1 day ago": [
            "ከ(\\d+) ቀን በፊት",
            "ከ(\\d+) ቀናት በፊት",
            "ከ (\\d+) ቀን በፊት",
            "ከ(\\d+) ቀኖች በፊት"
        ],
        "in \\1 hour": [
            "በ(\\d+) ሰዓት ውስጥ",
            "በ(\\d+) ሰዓቶች ውስጥ"
        ],
        "\\1 hour ago": [
            "ከ(\\d+) ሰዓት በፊት",
            "ከ(\\d+) ሰዓቶች በፊት"
        ],
        "in \\1 minute": [
            "በ(\\d+) ደቂቃ ውስጥ",
            "በ(\\d+) ደቂቃዎች ውስጥ"
        ],
        "\\1 minute ago": [
            "ከ(\\d+) ደቂቃ በፊት",
            "ከ(\\d+) ደቂቃዎች በፊት"
        ],
        "in \\1 second": [
            "በ(\\d+) ሰከንድ ውስጥ",
            "በ(\\d+) ሰከንዶች ውስጥ"
        ],
        "\\1 second ago": [
            "ከ(\\d+) ሰከንድ በፊት",
            "ከ(\\d+) ሰከንዶች በፊት"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# coding: utf-8

from umalqurra.hijri_date import HijriDate as hj
from umalqurra.ummalqura_arrray import UmalqurraArray
from dateparser.calendars import non_gregorian_parser


class hijri(object):

    @classmethod
    def to_gregorian(cls, year=None, month=None, day=None):
        h = hj(year=year, month=month, day=day)
        return int(h.year_gr), int(h.month_gr), int(h.day_gr)

    @classmethod
    def from_gregorian(cls, year=None, month=None, day=None):
        h = hj(year=year, month=month, day=day, gr=True)
        return int(h.year), int(h.month), int(h.day)

    @classmethod
    def month_length(cls, year, month):
        iy = year
        im = month
        id = 1
        ii = iy - 1
        iln = (ii * 12) + 1 + (im - 1)
        i = iln - 16260
        mcjdn = id + UmalqurraArray.ummalqura_dat[i - 1] - 1
        index = UmalqurraArray.get_index(mcjdn)
        ml = UmalqurraArray.ummalqura_dat[index] - UmalqurraArray.ummalqura_dat[index - 1]
        return ml


class HijriDate(object):
    def __init__(self, year, month, day):
        self.year = year
        self.month = month
        self.day = day

    def weekday(self):
        for week in hijri.monthcalendar(self.year, self.month):
            for idx, day in enumerate(week):
                if day == self.day:
                    return idx


class hijri_parser(non_gregorian_parser):

    calendar_converter = hijri
    default_year = 1389
    default_month = 1
    default_day = 1
    non_gregorian_date_cls = HijriDate

    _time_conventions = {
        'am': [u"صباحاً"],
        'pm': [u"مساءً"],
    }

    # TODO: Implement arabic to latin translation
    # replace_ methods according to the way native speakers write

    @classmethod
    def _replace_time_conventions(cls, source):
        result = source
        for latin, arabics in cls._time_conventions.items():
            for arabic in arabics:
                result = result.replace(arabic, latin)
        return result
